Documentation
¶
Overview ¶
Package awsutil provides support for testing AWS packages and applications.
Index ¶
- func AWSTestMain(m *testing.M, service **AWS, opts ...Option)
- func DefaultAWSConfig() aws.Config
- func SkipAWSTests(_ *testing.T)
- type AWS
- func (a *AWS) EC2(cfg aws.Config) *ec2.Client
- func (a *AWS) KMS(cfg aws.Config) *kms.Client
- func (a *AWS) S3(cfg aws.Config) *s3.Client
- func (a *AWS) SESV2(cfg aws.Config) *sesv2.Client
- func (a *AWS) SecretsManager(cfg aws.Config) *secretsmanager.Client
- func (a *AWS) Start() error
- func (a *AWS) Stop() error
- func (a *AWS) URL() string
- type Option
- type Options
- type Service
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultAWSConfig ¶
func SkipAWSTests ¶
Types ¶
type AWS ¶
type AWS struct {
// contains filtered or unexported fields
}
func NewLocalAWS ¶
func (*AWS) SecretsManager ¶
func (a *AWS) SecretsManager(cfg aws.Config) *secretsmanager.Client
type Option ¶
type Option func(o *Options)
func WithS3Tree ¶
WithS3Tree configures the local S3 instance with the contents of the specified directory. The first level of directories under dir are used as bucket names, the second and deeper levels as prefixes and objects within those buckets etc.
func WithSecretsManager ¶
func WithSecretsManager() Option
type Service ¶
type Service string
const ( S3 Service = Service(localstack.S3) SecretsManager Service = Service(localstack.SecretsManager) SES Service = Service(localstack.SES) )
Click to show internal directories.
Click to hide internal directories.